@@ -1,6 +1,6 @@
 # ==================================================================== #
 # TITLE                                                                #
-# Antimicrobial Resistance (AMR) Analysis for R                        #
+# Antimicrobial Resistance (AMR) Data Analysis for R                   #
 #                                                                      #
 # SOURCE                                                               #
 # https://github.com/msberends/AMR                                     #
@@ -20,13 +20,13 @@
 # useful, but it comes WITHOUT ANY WARRANTY OR LIABILITY.              #
 #                                                                      #
 # Visit our website for the full manual and a complete tutorial about  #
-# how to conduct AMR analysis: https://msberends.github.io/AMR/        #
+# how to conduct AMR data analysis: https://msberends.github.io/AMR/   #
 # ==================================================================== #
 
-#' PCA biplot with `ggplot2`
+#' PCA Biplot with `ggplot2`
 #'
 #' Produces a `ggplot2` variant of a so-called [biplot](https://en.wikipedia.org/wiki/Biplot) for PCA (principal component analysis), but is more flexible and more appealing than the base \R [biplot()] function.
-#' @inheritSection lifecycle Maturing lifecycle
+#' @inheritSection lifecycle Stable Lifecycle
 #' @param x an object returned by [pca()], [prcomp()] or [princomp()]
 #' @inheritParams stats::biplot.prcomp
 #' @param labels an optional vector of labels for the observations. If set, the labels will be placed below their respective points. When using the [pca()] function as input for `x`, this will be determined automatically based on the attribute `non_numeric_cols`, see [pca()].
@@ -57,11 +57,11 @@
 #' 4. Added total amount of explained variance as a caption in the plot
 #' 5. Cleaned all syntax based on the `lintr` package, fixed grammatical errors and added integrity checks
 #' 6. Updated documentation
-#' @details The colours for labels and points can be changed by adding another scale layer for colour, like `scale_colour_viridis_d()` or `scale_colour_brewer()`.
+#' @details The colours for labels and points can be changed by adding another scale layer for colour, such as `scale_colour_viridis_d()` and `scale_colour_brewer()`.
 #' @rdname ggplot_pca
 #' @export
 #' @examples 
-#' # `example_isolates` is a dataset available in the AMR package.
+#' # `example_isolates` is a data set available in the AMR package.
 #' # See ?example_isolates.
 #'
 #' # See ?pca for more info about Principal Component Analysis (PCA).
@@ -109,26 +109,26 @@ ggplot_pca <- function(x,
   
   stop_ifnot_installed("ggplot2")
   meet_criteria(x, allow_class = c("prcomp", "princomp", "PCA", "lda"))
-  meet_criteria(choices, allow_class = c("numeric", "integer"), has_length = 2)
+  meet_criteria(choices, allow_class = c("numeric", "integer"), has_length = 2, is_positive = TRUE, is_finite = TRUE)
   meet_criteria(scale, allow_class = c("numeric", "integer", "logical"), has_length = 1)
   meet_criteria(pc.biplot, allow_class = "logical", has_length = 1)
   meet_criteria(labels, allow_class = "character", allow_NULL = TRUE)
-  meet_criteria(labels_textsize, allow_class = c("numeric", "integer"), has_length = 1)
-  meet_criteria(labels_text_placement, allow_class = c("numeric", "integer"), has_length = 1)
+  meet_criteria(labels_textsize, allow_class = c("numeric", "integer"), has_length = 1, is_positive = TRUE, is_finite = TRUE)
+  meet_criteria(labels_text_placement, allow_class = c("numeric", "integer"), has_length = 1, is_positive = TRUE, is_finite = TRUE)
   meet_criteria(groups, allow_class = "character", allow_NULL = TRUE)
   meet_criteria(ellipse, allow_class = "logical", has_length = 1)
-  meet_criteria(ellipse_prob, allow_class = c("numeric", "integer"), has_length = 1)
-  meet_criteria(ellipse_size, allow_class = c("numeric", "integer"), has_length = 1)
-  meet_criteria(ellipse_alpha, allow_class = c("numeric", "integer"), has_length = 1)
-  meet_criteria(points_size, allow_class = c("numeric", "integer"), has_length = 1)
-  meet_criteria(points_alpha, allow_class = c("numeric", "integer"), has_length = 1)
+  meet_criteria(ellipse_prob, allow_class = c("numeric", "integer"), has_length = 1, is_positive = TRUE, is_finite = TRUE)
+  meet_criteria(ellipse_size, allow_class = c("numeric", "integer"), has_length = 1, is_positive = TRUE, is_finite = TRUE)
+  meet_criteria(ellipse_alpha, allow_class = c("numeric", "integer"), has_length = 1, is_positive = TRUE, is_finite = TRUE)
+  meet_criteria(points_size, allow_class = c("numeric", "integer"), has_length = 1, is_positive = TRUE, is_finite = TRUE)
+  meet_criteria(points_alpha, allow_class = c("numeric", "integer"), has_length = 1, is_positive = TRUE, is_finite = TRUE)
   meet_criteria(arrows, allow_class = "logical", has_length = 1)
   meet_criteria(arrows_colour, allow_class = "character", has_length = 1)
-  meet_criteria(arrows_size, allow_class = c("numeric", "integer"), has_length = 1)
-  meet_criteria(arrows_textsize, allow_class = c("numeric", "integer"), has_length = 1)
+  meet_criteria(arrows_size, allow_class = c("numeric", "integer"), has_length = 1, is_positive = TRUE, is_finite = TRUE)
+  meet_criteria(arrows_textsize, allow_class = c("numeric", "integer"), has_length = 1, is_positive = TRUE, is_finite = TRUE)
   meet_criteria(arrows_textangled, allow_class = "logical", has_length = 1)
-  meet_criteria(arrows_alpha, allow_class = c("numeric", "integer"), has_length = 1)
-  meet_criteria(base_textsize, allow_class = c("numeric", "integer"), has_length = 1)
+  meet_criteria(arrows_alpha, allow_class = c("numeric", "integer"), has_length = 1, is_positive = TRUE, is_finite = TRUE)
+  meet_criteria(base_textsize, allow_class = c("numeric", "integer"), has_length = 1, is_positive = TRUE, is_finite = TRUE)
   
   calculations <- pca_calculations(pca_model = x,
                                    groups = groups, 
