@@ -1,6 +1,6 @@
 # ==================================================================== #
 # TITLE                                                                #
-# Antimicrobial Resistance (AMR) Analysis for R                        #
+# Antimicrobial Resistance (AMR) Data Analysis for R                   #
 #                                                                      #
 # SOURCE                                                               #
 # https://github.com/msberends/AMR                                     #
@@ -20,13 +20,13 @@
 # useful, but it comes WITHOUT ANY WARRANTY OR LIABILITY.              #
 #                                                                      #
 # Visit our website for the full manual and a complete tutorial about  #
-# how to conduct AMR analysis: https://msberends.github.io/AMR/        #
+# how to conduct AMR data analysis: https://msberends.github.io/AMR/   #
 # ==================================================================== #
 
-#' Pattern matching with keyboard shortcut
+#' Pattern Matching with Keyboard Shortcut
 #'
-#' Convenient wrapper around [grep()] to match a pattern: `x %like% pattern`. It always returns a [`logical`] vector and is always case-insensitive (use `x %like_case% pattern` for case-sensitive matching). Also, `pattern` can be as long as `x` to compare items of each index in both vectors, or they both can have the same length to iterate over all cases.
-#' @inheritSection lifecycle Stable lifecycle
+#' Convenient wrapper around [grepl()] to match a pattern: `x %like% pattern`. It always returns a [`logical`] vector and is always case-insensitive (use `x %like_case% pattern` for case-sensitive matching). Also, `pattern` can be as long as `x` to compare items of each index in both vectors, or they both can have the same length to iterate over all cases.
+#' @inheritSection lifecycle Stable Lifecycle
 #' @param x a character vector where matches are sought, or an object which can be coerced by [as.character()] to a character vector.
 #' @param pattern a character string containing a regular expression (or [character] string for `fixed = TRUE`) to be matched in the given character vector. Coerced by [as.character()] to a character string if possible.  If a [character] vector of length 2 or more is supplied, the first element is used with a warning.
 #' @param ignore.case if `FALSE`, the pattern matching is *case sensitive* and if `TRUE`, case is ignored during matching.
@@ -39,12 +39,12 @@
 #' * Is case-insensitive (use `%like_case%` for case-sensitive matching)
 #' * Supports multiple patterns
 #' * Checks if `pattern` is a regular expression and sets `fixed = TRUE` if not, to greatly improve speed
-#' * Tries again with `perl = TRUE` if regex fails
+#' * Always uses compatibility with Perl
 #' 
 #' Using RStudio? The text `%like%` can also be directly inserted in your code from the Addins menu and can have its own Keyboard Shortcut like `Ctrl+Shift+L` or `Cmd+Shift+L` (see `Tools` > `Modify Keyboard Shortcuts...`).
 #' @source Idea from the [`like` function from the `data.table` package](https://github.com/Rdatatable/data.table/blob/master/R/like.R)
-#' @seealso [grep()]
-#' @inheritSection AMR Read more on our website!
+#' @seealso [grepl()]
+#' @inheritSection AMR Read more on Our Website!
 #' @examples
 #' # simple test
 #' a <- "This is a test"
@@ -53,13 +53,17 @@
 #' #> TRUE
 #' b %like% a
 #' #> FALSE
-#'
-#' # also supports multiple patterns, length must be equal to x
+#' 
+#' # also supports multiple patterns
 #' a <- c("Test case", "Something different", "Yet another thing")
 #' b <- c(     "case",           "diff",      "yet")
 #' a %like% b
 #' #> TRUE TRUE TRUE
-#'
+#' a[1] %like% b
+#' #> TRUE FALSE FALSE
+#' a %like% b[1]
+#' #> TRUE FALSE FALSE
+#' 
 #' # get isolates whose name start with 'Ent' or 'ent'
 #' \donttest{
 #' if (require("dplyr")) {
@@ -71,7 +75,11 @@ like <- function(x, pattern, ignore.case = TRUE) {
   meet_criteria(x, allow_NA = TRUE)
   meet_criteria(pattern, allow_NA = FALSE)
   meet_criteria(ignore.case, allow_class = "logical", has_length = 1)
-
+  
+  if (all(is.na(x))) {
+    return(rep(FALSE, length(x)))
+  }
+  
   # set to fixed if no regex found
   fixed <- !any(is_possibly_regex(pattern))
   if (ignore.case == TRUE) {
@@ -79,66 +87,25 @@ like <- function(x, pattern, ignore.case = TRUE) {
     x <- tolower(x)
     pattern <- tolower(pattern)
   }
-  
-  if (length(pattern) > 1 & length(x) == 1) {
-    x <- rep(x, length(pattern))
-  }
-  
-  if (all(is.na(x))) {
-    return(rep(FALSE, length(x)))
-  }
-    
-  if (length(pattern) > 1) {
-    res <- vector(length = length(pattern))
-    if (length(x) != length(pattern)) {
-      if (length(x) == 1) {
-        x <- rep(x, length(pattern))
-      }
-      # return TRUE for every 'x' that matches any 'pattern', FALSE otherwise
-      for (i in seq_len(length(res))) {
-        if (is.factor(x[i])) {
-          res[i] <- as.integer(x[i]) %in% grep(pattern[i], levels(x[i]), ignore.case = FALSE, fixed = fixed)
-        } else {
-          res[i] <- grepl(pattern[i], x[i], ignore.case = FALSE, fixed = fixed)
-        }
-      }
-      res <- vapply(FUN.VALUE = logical(1), pattern, function(pttrn) grepl(pttrn, x, ignore.case = FALSE, fixed = fixed))
-      res2 <- as.logical(rowSums(res))
-      # get only first item of every hit in pattern
-      res2[duplicated(res)] <- FALSE
-      res2[rowSums(res) == 0] <- NA
-      return(res2)
-    } else {
-      # x and pattern are of same length, so items with each other
-      for (i in seq_len(length(res))) {
-        if (is.factor(x[i])) {
-          res[i] <- as.integer(x[i]) %in% grep(pattern[i], levels(x[i]), ignore.case = FALSE, fixed = fixed)
-        } else {
-          res[i] <- grepl(pattern[i], x[i], ignore.case = FALSE, fixed = fixed)
-        }
-      }
-      return(res)
-    }
-  }
-  
-  # the regular way how grepl works; just one pattern against one or more x
+
   if (is.factor(x)) {
-    as.integer(x) %in% grep(pattern, levels(x), ignore.case = FALSE, fixed = fixed)
+    x <- as.character(x)
+  }
+  
+  if (length(pattern) == 1) {
+    grepl(pattern, x, ignore.case = FALSE, fixed = fixed, perl = !fixed)
   } else {
-    tryCatch(grepl(pattern, x, ignore.case = FALSE, fixed = fixed),
-             error = function(e) {
-               if (grepl("invalid reg(ular )?exp", e$message, ignore.case = TRUE)) {
-                 # try with perl = TRUE:
-                 return(grepl(pattern = pattern, 
-                                    x = x,
-                                    ignore.case = FALSE, 
-                                    fixed = fixed,
-                                    perl = TRUE))
-               } else {
-                 # stop otherwise
-                 stop(e$message)
-               }
-             })
+    if (length(x) == 1) {
+      x <- rep(x, length(pattern))
+    } else if (length(pattern) != length(x)) {
+      stop_("arguments `x` and `pattern` must be of same length, or either one must be 1")
+    }
+    unlist(
+      Map(f = grepl,
+          pattern,
+          x,
+          MoreArgs = list(ignore.case = FALSE, fixed = fixed, perl = !fixed)),
+      use.names = FALSE)
   }
 }
 
@@ -157,15 +124,3 @@ like <- function(x, pattern, ignore.case = TRUE) {
   meet_criteria(pattern, allow_NA = FALSE)
   like(x, pattern, ignore.case = FALSE)
 }
-
-"%like_perl%" <- function(x, pattern) {
-  meet_criteria(x, allow_NA = TRUE)
-  meet_criteria(pattern, allow_NA = FALSE)
-  # convenient for e.g. matching all Klebsiella and Raoultella, but not 
-  # K. aerogenes: fullname %like_perl% "^(Klebsiella(?! aerogenes)|Raoultella)"
-  grepl(x = tolower(x),
-        pattern = tolower(pattern),
-        perl = TRUE,
-        fixed = FALSE,
-        ignore.case = TRUE)
-}
