@@ -1,6 +1,6 @@
 # ==================================================================== #
 # TITLE                                                                #
-# Antimicrobial Resistance (AMR) Analysis for R                        #
+# Antimicrobial Resistance (AMR) Data Analysis for R                   #
 #                                                                      #
 # SOURCE                                                               #
 # https://github.com/msberends/AMR                                     #
@@ -20,27 +20,27 @@
 # useful, but it comes WITHOUT ANY WARRANTY OR LIABILITY.              #
 #                                                                      #
 # Visit our website for the full manual and a complete tutorial about  #
-# how to conduct AMR analysis: https://msberends.github.io/AMR/        #
+# how to conduct AMR data analysis: https://msberends.github.io/AMR/   #
 # ==================================================================== #
 
-#' Translate strings from AMR package
+#' Translate Strings from AMR Package
 #'
 #' For language-dependent output of AMR functions, like [mo_name()], [mo_gramstain()], [mo_type()] and [ab_name()].
-#' @inheritSection lifecycle Stable lifecycle
+#' @inheritSection lifecycle Stable Lifecycle
 #' @details Strings will be translated to foreign languages if they are defined in a local translation file. Additions to this file can be suggested at our repository. The file can be found here: <https://github.com/msberends/AMR/blob/master/data-raw/translations.tsv>. This file will be read by all functions where a translated output can be desired, like all [`mo_*`][mo_property()] functions (such as [mo_name()], [mo_gramstain()], [mo_type()], etc.) and [`ab_*`][ab_property()] functions (such as [ab_name()], [ab_group()], etc.). 
 #'
-#' Currently supported languages are: `r paste(sort(gsub(";.*", "", ISOcodes::ISO_639_2[which(ISOcodes::ISO_639_2$Alpha_2 %in% LANGUAGES_SUPPORTED), "Name"])), collapse = ", ")`. Please note that currently not all these languages have translations available for all antimicrobial agents and colloquial microorganism names. 
+#' Currently supported languages are: `r vector_and(gsub(";.*", "", ISOcodes::ISO_639_2[which(ISOcodes::ISO_639_2$Alpha_2 %in% LANGUAGES_SUPPORTED), "Name"]), quotes = FALSE)`. Please note that currently not all these languages have translations available for all antimicrobial agents and colloquial microorganism names. 
 #'
 #' Please suggest your own translations [by creating a new issue on our repository](https://github.com/msberends/AMR/issues/new?title=Translations).
 #'
-#' ## Changing the default language
+#' ## Changing the Default Language
 #' The system language will be used at default (as returned by `Sys.getenv("LANG")` or, if `LANG` is not set, [Sys.getlocale()]), if that language is supported. But the language to be used can be overwritten in two ways and will be checked in this order:
 #' 
 #'   1. Setting the R option `AMR_locale`, e.g. by running `options(AMR_locale = "de")`
 #'   2. Setting the system variable `LANGUAGE` or `LANG`, e.g. by adding `LANGUAGE="de_DE.utf8"` to your `.Renviron` file in your home directory
 #' 
 #' So if the R option `AMR_locale` is set, the system variables `LANGUAGE` and `LANG` will be ignored.
-#' @inheritSection AMR Read more on our website!
+#' @inheritSection AMR Read more on Our Website!
 #' @rdname translate
 #' @name translate
 #' @export
@@ -83,8 +83,8 @@ get_locale <- function() {
     if (lang %in% LANGUAGES_SUPPORTED) {
       return(lang)
     } else {
-      stop_("unsupported language set as option 'AMR_locale': '", lang, "' - use one of: ",
-            paste0("'", LANGUAGES_SUPPORTED, "'", collapse = ", "))
+      stop_("unsupported language set as option 'AMR_locale': \"", lang, "\" - use either ",
+            vector_or(LANGUAGES_SUPPORTED, quotes = TRUE))
     }
   } else {
     # we now support the LANGUAGE system variable - return it if set
@@ -123,7 +123,7 @@ coerce_language_setting <- function(lang) {
 }
 
 # translate strings based on inst/translations.tsv
-translate_AMR <- function(from, language = get_locale(), only_unknown = FALSE) {
+translate_AMR <- function(from, language = get_locale(), only_unknown = FALSE, affect_mo_name = FALSE) {
   
   if (is.null(language)) {
     return(from)
@@ -138,19 +138,23 @@ translate_AMR <- function(from, language = get_locale(), only_unknown = FALSE) {
   from_unique_translated <- from_unique
   
   stop_ifnot(language %in% LANGUAGES_SUPPORTED,
-             "unsupported language: '", language, "' - use one of: ",
-             paste0("'", LANGUAGES_SUPPORTED, "'", collapse = ", "),
+             "unsupported language: \"", language, "\" - use either ",
+             vector_or(LANGUAGES_SUPPORTED, quotes = TRUE),
              call = FALSE)
   
-  df_trans <- subset(df_trans, lang == language)
+  # only keep lines where translation is available for this language
+  df_trans <- df_trans[which(!is.na(df_trans[, language, drop = TRUE])), , drop = FALSE]
   if (only_unknown == TRUE) {
     df_trans <- subset(df_trans, pattern %like% "unknown")
   }
+  if (affect_mo_name == TRUE) {
+    df_trans <- subset(df_trans, affect_mo_name == TRUE)
+  }
   
-  # default case sensitive if value if 'ignore.case' is missing:
-  df_trans$ignore.case[is.na(df_trans$ignore.case)] <- FALSE
-  # default not using regular expressions (fixed = TRUE) if 'fixed' is missing:
-  df_trans$fixed[is.na(df_trans$fixed)] <- TRUE
+  # default: case sensitive if value if 'case_sensitive' is missing:
+  df_trans$case_sensitive[is.na(df_trans$case_sensitive)] <- TRUE
+  # default: not using regular expressions if 'regular_expr' is missing:
+  df_trans$regular_expr[is.na(df_trans$regular_expr)] <- FALSE
   
   # check if text to look for is in one of the patterns
   any_form_in_patterns <- tryCatch(any(from_unique %like% paste0("(", paste(df_trans$pattern, collapse = "|"), ")")),
@@ -164,10 +168,11 @@ translate_AMR <- function(from, language = get_locale(), only_unknown = FALSE) {
   
   lapply(seq_len(nrow(df_trans)), 
          function(i) from_unique_translated <<- gsub(pattern = df_trans$pattern[i],
-                                                     replacement = df_trans$replacement[i],
+                                                     replacement = df_trans[i, language, drop = TRUE],
                                                      x = from_unique_translated,
-                                                     ignore.case = df_trans$ignore.case[i], 
-                                                     fixed = df_trans$fixed[i]))
+                                                     ignore.case = !df_trans$case_sensitive[i], 
+                                                     fixed = !df_trans$regular_expr[i],
+                                                     perl = df_trans$regular_expr[i]))
   
   # force UTF-8 for diacritics
   from_unique_translated <- enc2utf8(from_unique_translated)
