@@ -40,26 +40,22 @@ dates <- seq(as.Date("2010-01-01"), as.Date("2018-01-01"), by = "day")
 bacteria <- c("Escherichia coli", "Staphylococcus aureus",
               "Streptococcus pneumoniae", "Klebsiella pneumoniae")
 
-## ----create other-------------------------------------------------------------
-hospitals <- c("Hospital A", "Hospital B", "Hospital C", "Hospital D")
-ab_interpretations <- c("S", "I", "R")
-
 ## ----merge data---------------------------------------------------------------
 sample_size <- 20000
 data <- data.frame(date = sample(dates, size = sample_size, replace = TRUE),
                    patient_id = sample(patients, size = sample_size, replace = TRUE),
-                   hospital = sample(hospitals, size = sample_size, replace = TRUE,
+                   hospital = sample(c("Hospital A",
+                                       "Hospital B",
+                                       "Hospital C",
+                                       "Hospital D"),
+                                     size = sample_size, replace = TRUE,
                                      prob = c(0.30, 0.35, 0.15, 0.20)),
                    bacteria = sample(bacteria, size = sample_size, replace = TRUE,
                                      prob = c(0.50, 0.25, 0.15, 0.10)),
-                   AMX = sample(ab_interpretations, size = sample_size, replace = TRUE,
-                                 prob = c(0.60, 0.05, 0.35)),
-                   AMC = sample(ab_interpretations, size = sample_size, replace = TRUE,
-                                 prob = c(0.75, 0.10, 0.15)),
-                   CIP = sample(ab_interpretations, size = sample_size, replace = TRUE,
-                                 prob = c(0.80, 0.00, 0.20)),
-                   GEN = sample(ab_interpretations, size = sample_size, replace = TRUE,
-                                 prob = c(0.92, 0.00, 0.08)))
+                   AMX = random_rsi(sample_size, prob_RSI = c(0.35, 0.60, 0.05)),
+                   AMC = random_rsi(sample_size, prob_RSI = c(0.15, 0.75, 0.10)),
+                   CIP = random_rsi(sample_size, prob_RSI = c(0.20, 0.80, 0.00)),
+                   GEN = random_rsi(sample_size, prob_RSI = c(0.08, 0.92, 0.00)))
 
 ## ----merge data 2, message = FALSE, warning = FALSE---------------------------
 data <- data %>% left_join(patients_table)
@@ -82,7 +78,7 @@ data <- data %>%
   mutate_at(vars(AMX:GEN), as.rsi)
 
 ## ----eucast, warning = FALSE, message = FALSE---------------------------------
-data <- eucast_rules(data, col_mo = "bacteria")
+data <- eucast_rules(data, col_mo = "bacteria", rules = "all")
 
 ## ----new taxo-----------------------------------------------------------------
 data <- data %>% 
@@ -92,7 +88,7 @@ data <- data %>%
 
 ## ----1st isolate--------------------------------------------------------------
 data <- data %>% 
-  mutate(first = first_isolate(.))
+  mutate(first = first_isolate())
 
 ## ----1st isolate filter-------------------------------------------------------
 data_1st <- data %>% 
@@ -104,7 +100,7 @@ data_1st <- data %>%
 
 ## ---- echo = FALSE, message = FALSE, warning = FALSE, results = 'asis'--------
 weighted_df <- data %>%
-  filter(bacteria == as.mo("E. coli")) %>% 
+  filter(bacteria == as.mo("Escherichia coli")) %>% 
   # only most prevalent patient
   filter(patient_id == top_freq(freq(., patient_id), 1)[1]) %>% 
   arrange(date) %>%
@@ -120,12 +116,12 @@ weighted_df %>%
 
 ## ----1st weighted, warning = FALSE--------------------------------------------
 data <- data %>% 
-  mutate(keyab = key_antibiotics(.)) %>% 
-  mutate(first_weighted = first_isolate(.))
+  mutate(keyab = key_antibiotics()) %>% 
+  mutate(first_weighted = first_isolate())
 
 ## ---- echo = FALSE, message = FALSE, warning = FALSE, results = 'asis'--------
 weighted_df2 <- data %>%
-  filter(bacteria == as.mo("E. coli")) %>% 
+  filter(bacteria == as.mo("Escherichia coli")) %>% 
   # only most prevalent patient
   filter(patient_id == top_freq(freq(., patient_id), 1)[1]) %>% 
   arrange(date) %>%
@@ -162,6 +158,28 @@ knitr::kable(head(data_1st), align = "c")
 data_1st %>% 
   freq(genus, species, header = TRUE)
 
+## ----bug_drg 1a, eval = FALSE-------------------------------------------------
+#  data_1st %>%
+#    bug_drug_combinations() %>%
+#    head() # show first 6 rows
+
+## ----bug_drg 1b, echo = FALSE, results = 'asis'-------------------------------
+knitr::kable(data_1st %>% 
+               bug_drug_combinations() %>% 
+               head(),
+             align = "c")
+
+## ----bug_drg 2a, eval = FALSE-------------------------------------------------
+#  data_1st %>%
+#    select(bacteria, fluoroquinolones()) %>%
+#    bug_drug_combinations()
+
+## ----bug_drg 2b, echo = FALSE, results = 'asis'-------------------------------
+knitr::kable(data_1st %>% 
+               select(bacteria, fluoroquinolones()) %>% 
+               bug_drug_combinations(),
+             align = "c")
+
 ## -----------------------------------------------------------------------------
 data_1st %>% resistance(AMX)
 
@@ -244,7 +262,7 @@ ggplot(data_1st %>% group_by(genus)) +
   geom_rsi(x = "genus") + 
   # split plots on antibiotic
   facet_rsi(facet = "antibiotic") +
-  # set colours to the R/SI interpretations
+  # set colours to the R/SI interpretations (colour-blind friendly)
   scale_rsi_colours() +
   # show percentages on y axis
   scale_y_percent(breaks = 0:4 * 25) +
@@ -266,6 +284,39 @@ data_1st %>%
              datalabels = FALSE) +
   coord_flip()
 
+## ---- results='markup'--------------------------------------------------------
+mic_values <- random_mic(size = 100)
+mic_values
+
+## ----mic_plots----------------------------------------------------------------
+# base R:
+plot(mic_values)
+# ggplot2:
+ggplot(mic_values)
+
+## ---- results = 'markup', message = FALSE, warning = FALSE--------------------
+mic_values <- random_mic(size = 100, mo = "E. coli", ab = "cipro")
+
+## ----mic_plots_mo_ab, message = FALSE, warning = FALSE------------------------
+# base R:
+plot(mic_values, mo = "E. coli", ab = "cipro")
+# ggplot2:
+ggplot(mic_values, mo = "E. coli", ab = "cipro")
+
+## ---- results = 'markup'------------------------------------------------------
+disk_values <- random_disk(size = 100, mo = "E. coli", ab = "cipro")
+disk_values
+
+## ----disk_plots, message = FALSE, warning = FALSE-----------------------------
+# base R:
+plot(disk_values, mo = "E. coli", ab = "cipro")
+
+## ----disk_plots_mo_ab, message = FALSE, warning = FALSE-----------------------
+ggplot(disk_values,
+       mo = "E. coli",
+       ab = "cipro",
+       guideline = "CLSI")
+
 ## ---- results = 'markup'------------------------------------------------------
 # use package 'tidyr' to pivot data:
 library(tidyr)
