@@ -1,6 +1,6 @@
 # ==================================================================== #
 # TITLE                                                                #
-# Antimicrobial Resistance (AMR) Analysis for R                        #
+# Antimicrobial Resistance (AMR) Data Analysis for R                   #
 #                                                                      #
 # SOURCE                                                               #
 # https://github.com/msberends/AMR                                     #
@@ -20,7 +20,7 @@
 # useful, but it comes WITHOUT ANY WARRANTY OR LIABILITY.              #
 #                                                                      #
 # Visit our website for the full manual and a complete tutorial about  #
-# how to conduct AMR analysis: https://msberends.github.io/AMR/        #
+# how to conduct AMR data analysis: https://msberends.github.io/AMR/   #
 # ==================================================================== #
 
 context("ggplot_rsi.R")
@@ -71,5 +71,19 @@ test_that("ggplot_rsi works", {
                         ggplot(aes(x = ab, y = n)) +
                         geom_col())$data),
                "data.frame")
-
+  
+  expect_equal(class((data.frame(ab = as.ab(c("amx", "amc")),
+                                 n = c(40, 100)) %>%
+                        ggplot(aes(x = ab, y = n)) +
+                        geom_col())$data),
+               "data.frame")
+  
+  # support for manual colours
+  expect_equal(class((ggplot(data.frame(x = c("Value1", "Value2", "Value3"),
+                                        y = c(1, 2, 3),
+                                        z = c("Value4", "Value5", "Value6"))) +
+                        geom_col(aes(x = x, y = y, fill = z)) +
+                        scale_rsi_colours(Value4 = "S", Value5 = "I", Value6 = "R"))$data),
+               "data.frame")
+  
 })
